@@ -1,6 +1,6 @@
 /*
     fileio
-    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,16 +16,12 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "fileio.h"
-#include <time.h>
 #ifdef HAVE_UTIME_H
 # include <utime.h>
 #endif /* HAVE_UTIME_H */
 #if defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME_H)
 # include <sys/time.h>
 #endif /* defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME_H) */
-#if GLIB_CHECK_VERSION(2,6,0)
-# include <glib/gstdio.h>
-#endif /* GLIB_CHECK_VERSION(2,6,0) */
 #if defined (G_OS_WIN32)
 # include <shlwapi.h>
 #elif GLIB_CHECK_VERSION(2,16,0)
@@ -364,7 +360,7 @@ fileio_get_absolute_path (const gchar *file,
   while (i < leng)
     if (G_IS_DIR_SEPARATOR (absolate[i]) && absolate[i + 1] == '.'
         && absolate[i + 2] == '.'
-        && (G_IS_DIR_SEPARATOR (absolate[i + 3])  || absolate[i + 3] == '\0'))
+        && (G_IS_DIR_SEPARATOR (absolate[i + 3]) || absolate[i + 3] == '\0'))
       {
         gint j;
 
@@ -510,8 +506,7 @@ fileio_open (const gchar *file,
 # endif /* not GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
   int fd, flags;
-  gint i;
-  guint length;
+  GList *glist;
 #endif /* not G_OS_WIN32 */
 
   if (!file)
@@ -615,25 +610,21 @@ fileio_open (const gchar *file,
   G_LOCK (critical);
   critical = TRUE;
 # endif /* USE_THREAD */
-  length = g_list_length (glist_fileio);
-  for (i = 0; i < length; i++)
-    {
-      fio = g_list_nth_data (glist_fileio, i);
-      if (g_strfilecmp (fio->file, path) == 0
-                                            && (fio->share & access) != access)
-        break;
-    }
+  for (glist = g_list_first (glist_fileio); glist; glist = g_list_next (glist))
+    if (g_strfilecmp (((FileIO *)glist->data)->file, path) == 0
+                        && (((FileIO *)glist->data)->share & access) != access)
+      break;
 # ifdef USE_THREAD
   critical = FALSE;
   G_UNLOCK (critical);
 # endif /* USE_THREAD */
-  if (i < length)
+  if (glist)
     {
       g_free (path);
       return NULL;
     }
 
-  fd = open (path, flags,
+  fd = g_open (path, flags,
                     S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);
   if (fd == -1)
     {
@@ -647,7 +638,7 @@ fileio_open (const gchar *file,
 # endif /* HAVE_FLOCK */
         (mode == FILEIO_MODE_CREATE_ALWAYS && (
 # ifdef HAVE_FTRUNCATE
-                    ftruncate (fd, 0) || 
+                    ftruncate (fd, 0) ||
 # endif /* HAVE_FTRUNCATE */
                     lseek (fd, 0, SEEK_SET) == -1)))
     {
@@ -917,7 +908,7 @@ fileio_eof (FileIO *fio)
   critical = TRUE;
 #  endif /* USE_THREAD */
   result = fio && g_list_find (glist_fileio, fio)
-                                    ? ftruncate (fio->fd, offset) == 0: FALSE;
+                                    ? ftruncate (fio->fd, offset) == 0 : FALSE;
 #  ifdef USE_THREAD
   critical = FALSE;
   G_UNLOCK (critical);
@@ -1158,13 +1149,8 @@ fileio_mkdir (const gchar *dir)
     }
 # endif /* GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
-# if GLIB_CHECK_VERSION(2,6,0)
   result = g_mkdir (path, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP
                                                     | S_IROTH | S_IXOTH) == 0;
-# else /* not GLIB_CHECK_VERSION(2,6,0) */
-  result = mkdir (path, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP
-                                                    | S_IROTH | S_IXOTH) == 0;
-# endif /* not GLIB_CHECK_VERSION(2,6,0) */
 #endif /* not G_OS_WIN32 */
   g_free (path);
   return result;
@@ -1241,11 +1227,7 @@ fileio_remove (const gchar *path)
             }
 # endif /* GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
-# if GLIB_CHECK_VERSION(2,6,0)
           result = g_rmdir (path) == 0;
-# else /* not GLIB_CHECK_VERSION(2,6,0) */
-          result = rmdir (path) == 0;
-# endif /* not GLIB_CHECK_VERSION(2,6,0) */
 #endif /* not G_OS_WIN32 */
         }
     }
@@ -1294,11 +1276,7 @@ fileio_remove (const gchar *path)
         }
 # endif /* GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
-# if GLIB_CHECK_VERSION(2,6,0)
       result = g_remove (path) == 0;
-# else /* not GLIB_CHECK_VERSION(2,6,0) */
-      result = remove (path) == 0;
-# endif /* not GLIB_CHECK_VERSION(2,6,0) */
 #endif /* not G_OS_WIN32 */
     }
   return result;
@@ -1392,7 +1370,7 @@ fileio_gettime (const gchar *file,
     }
 # endif /* GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
-  if (stat (file, &buf))
+  if (g_stat (file, &buf))
     return FALSE;
   if (atime)
     *atime = buf.st_atime;
@@ -1480,7 +1458,7 @@ fileio_settime (const gchar *file,
   return CloseHandle (hFile);
 #else /* not G_OS_WIN32 */
 # ifdef HAVE_UTIME
-  if (stat (file, &sbuf))
+  if (g_stat (file, &sbuf))
     return FALSE;
   ubuf.actime  = atime ? *atime : sbuf.st_atime;
   ubuf.modtime = mtime ? *mtime : sbuf.st_mtime;
