@@ -1,10 +1,10 @@
 /*
     fileio
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,38 +13,35 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef __FILEIO_H__
 #define __FILEIO_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>
-#endif
+#endif /* HAVE_FCNTL_H */
 #ifdef HAVE_SYS_FILE_H
 # include <sys/file.h>
-#endif
+#endif /* HAVE_SYS_FILE_H */
 #ifdef HAVE_SYS_STAT_H
 # include <sys/stat.h>
-#endif
+#endif /* HAVE_SYS_STAT_H */
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>
-#endif
+#endif /* HAVE_SYS_TYPES_H */
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
-#endif
+#endif /* HAVE_UNISTD_H */
 #ifdef G_OS_WIN32
 # include <tchar.h>
 # include <windows.h>
-#endif
+#endif /* G_OS_WIN32 */
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 #ifdef G_OS_WIN32
@@ -73,16 +70,8 @@ extern "C" {
 # define FILEIO_SEEK_END            SEEK_END
 #endif /* not G_OS_WIN32 */
 #define FILEIO_SHARE_DENY           0
-#define FILEIO_ACCESS_ALL           (FILEIO_ACCESS_READ | FILEIO_ACCESS_WRITE)
-#define FILEIO_SHARE_ALL            (FILEIO_SHARE_READ | FILEIO_SHARE_WRITE)
-#define FILEIO_TEST_IS_REGULAR      (1 << 0)
-#define FILEIO_TEST_IS_SYMLINK      (1 << 1)
-#define FILEIO_TEST_IS_DIR          (1 << 2)
-#define FILEIO_TEST_IS_EXECUTABLE   (1 << 3)
-#define FILEIO_TEST_EXISTS          (1 << 4)
-
-
-#define fileio_isfile(file) g_file_test(file,G_FILE_TEST_EXISTS)
+#define FILEIO_ACCESS_ALL           (FILEIO_ACCESS_READ|FILEIO_ACCESS_WRITE)
+#define FILEIO_SHARE_ALL            (FILEIO_SHARE_READ|FILEIO_SHARE_WRITE)
 
 
 typedef struct _FileIO FileIO;
@@ -106,18 +95,9 @@ typedef struct _FileIOSysTime
 
 /******************************************************************************
 *                                                                             *
-* ja:ファイル入出力関数群                                                     *
+* ja:ファイル名関数群                                                         *
 *                                                                             *
 ******************************************************************************/
-/*  ja:ファイルの存在確認
-    file,ファイル名
-    test,条件
-     RET,TRUE:合致する,FALSE:合致しない                                     */
-gboolean
-fileio_test (const gchar *file,
-             const guint test);
-
-
 /*  ja:ファイルのフルパスを取得する
     file,ファイル名
      RET,フルパス                                                           */
@@ -142,6 +122,11 @@ fileio_get_relative_path (const gchar *file,
                           const gchar *path);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:低レベルファイル入出力関数群                                             *
+*                                                                             *
+******************************************************************************/
 /*  ja:ファイルの作成
       file,ファイル名
     access,アクセス
@@ -155,11 +140,31 @@ fileio_open (const gchar *file,
              const guint  mode);
 
 
-/*  ja:ファイルポインタを閉じる
+/*  ja:ファイルポインタの参照数を増やす
     fio,ファイルポインタ
     RET,TRUE:正常終了,FALSE:エラー                                          */
 gboolean
-fileio_close (FileIO *fio);
+fileio_ref (FileIO *fio);
+
+
+/*  ja:ファイルポインタの参照数を減らす
+    fio,ファイルポインタ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+gboolean
+fileio_unref (FileIO *fio);
+
+
+/*  ja:ファイルポインタを閉じる
+    fio,ファイルポインタ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+#define fileio_close(fio) fileio_unref(fio)
+
+
+/*  ja:ファイルの名前を取得する
+    fio,ファイルポインタ
+    RET,名前(フルパス)                                                      */
+const gchar *
+fileio_getname (FileIO *fio);
 
 
 /*  ja:ファイルから読み込む
@@ -179,9 +184,9 @@ fileio_read (FileIO       *fio,
     length,バイト数
        RET,バイト数,-1:エラー                                               */
 gssize
-fileio_write (FileIO       *fio,
-              gpointer      data,
-              const gssize  length);
+fileio_write (FileIO        *fio,
+              gconstpointer  data,
+              const gssize   length);
 
 
 /*  ja:ファイルをシークする
@@ -195,6 +200,45 @@ fileio_seek (FileIO        *fio,
              const guint    whence);
 
 
+/*  ja:ファイルサイズを求める
+    fio,ファイルポインタ
+    RET,ファイルサイズ,-1:エラー                                            */
+goffset
+fileio_size (FileIO *fio);
+
+
+/*  ja:ファイルの終端を設定する
+    fio,ファイルポインタ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+gboolean
+fileio_eof (FileIO *fio);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:高レベルファイル入出力関数群                                             *
+*                                                                             *
+******************************************************************************/
+/*  ja:ファイルをメモリに読み込む
+      file,ファイル名
+    length,ファイルサイズ
+       RET,メモリ,NULL:エラー                                               */
+gpointer
+fileio_load (const gchar *file,
+             gssize      *length);
+
+
+/*  ja:ファイルにメモリから書き込む
+      file,ファイル名
+      data,メモリ
+    length,サイズ
+       RET,TRUE:正常終了,FALSE:エラー                                       */
+gboolean
+fileio_save (const gchar   *file,
+             gconstpointer  data,
+             const gssize   length);
+
+
 /*  ja:1文字読み込む
     fio,ファイルポインタ
     RET,文字,EOF:エラー                                                     */
@@ -228,10 +272,34 @@ fileio_gets (gchar       *data,
        fio,ファイルポインタ
        RET,正数:正常終了,EOF:エラー                                         */
 gint
-fileio_puts (gchar  *data,
-             FileIO *fio);
+fileio_puts (const gchar *data,
+             FileIO      *fio);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:ディレクトリ関数群                                                       *
+*                                                                             *
+******************************************************************************/
+/*  ja:ディレクトリを作る
+    dir,ディレクトリ名
+    RET,TRUE:正常終了,FALSE,エラー                                          */
+gboolean
+fileio_mkdir (const gchar *dir);
+
+
+/*  ja:ファイル/ディレクトリを削除する
+    path,ファイル/ディレクトリ名
+     RET,TRUE:正常終了,FALSE,エラー                                         */
+gboolean
+fileio_remove (const gchar *path);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:ファイル時刻関数群                                                       *
+*                                                                             *
+******************************************************************************/
 /*  ja:ファイルの時刻を取得する
      file,ファイル名
     atime,最終アクセス時刻
@@ -254,24 +322,37 @@ fileio_settime (const gchar *file,
                 FileIOTime  *mtime);
 
 
-/*  ja:ファイルの時刻を変換する
+/*  ja:システム時刻を取得する
     ftime,ファイルの時刻
-    stime,システム時刻                                                      */
+    stime,システム時間                                                      */
 void
 fileio_getsystime (FileIOTime    *ftime,
                    FileIOSysTime *stime);
 
 
+/*  ja:システム時刻を設定する
+    ftime,ファイルの時刻
+    stime,システム時間                                                      */
+void
+fileio_setsystime (FileIOTime    *ftime,
+                   FileIOSysTime *stime);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:応用ファイル関数群                                                       *
+*                                                                             *
+******************************************************************************/
 /*  ja:ファイルのアイコンを取得する
-    file,ファイル名
-     RET,pixbuf,NULL:エラー                                                 */
+         file,ファイル名
+    icon_size,アイコンサイズ
+          RET,pixbuf,NULL:エラー                                            */
 GdkPixbuf *
-fileio_extract_icon (const gchar *file);
+fileio_extract_icon (const gchar *file,
+                     GtkIconSize  icon_size);
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 
 #endif /* __FILEIO_H__ */
