@@ -1,6 +1,6 @@
 /*
     profile
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,12 +43,12 @@ struct _Profile
 
 /******************************************************************************
 *                                                                             *
-* ja:t@C֐Q()                                               *
+* ja:初期化ファイル関数群(内部)                                               *
 *                                                                             *
 ******************************************************************************/
-/*  ja:XgeLXg
-    profile_list,Xg
-             RET,eLXgXg                                             */
+/*  ja:リストをテキスト化する
+    profile_list,リスト
+             RET,テキストリスト                                             */
 static gchar *
 profile_list_to_text (ProfileList *profile_list)
 {
@@ -72,9 +72,9 @@ profile_list_to_text (ProfileList *profile_list)
 }
 
 
-/*  ja:eLXgXg
-    text,eLXg
-     RET,Xg                                                             */
+/*  ja:テキストをリスト化する
+    text,テキスト
+     RET,リスト                                                             */
 static ProfileList *
 profile_list_from_text (const gchar *text)
 {
@@ -82,13 +82,13 @@ profile_list_from_text (const gchar *text)
   gint i, j = 0;
   ProfileList *p = NULL, *q, *r;
 
-  /* ja:CRLFLFɕϊ */
+  /* ja:CRLFをLFに変換する */
   buf = g_strdup (text);
   for (i = 0; buf[i] != '\0'; i++)
     if (buf[i] != '\r' || buf[i + 1] != '\n')
       buf[j++] = buf[i];
   buf[j] = '\0';
-  /* ja:CRLFɕϊ */
+  /* ja:CRをLFに変換する */
   for (i = 0; buf[i] != '\0'; i++)
     if (buf[i] == '\r')
       buf[i] = '\n';
@@ -108,7 +108,7 @@ profile_list_from_text (const gchar *text)
     while (p->prev)
       p = p->prev;
   r = p;
-  /* ja:Xg𐮗 */
+  /* ja:リストを整理する */
   while (p)
     {
       gsize n;
@@ -155,9 +155,9 @@ profile_list_from_text (const gchar *text)
 }
 
 
-/*  ja:t@CXg
-    file,t@C
-     RET,Xg                                                             */
+/*  ja:ファイルをリスト化する
+    file,ファイル名
+     RET,リスト                                                             */
 static ProfileList *
 profile_list_from_file (const gchar *file)
 {
@@ -177,8 +177,8 @@ profile_list_from_file (const gchar *file)
 }
 
 
-/*  ja:t@C
-    profile_list,Xg                                                     */
+/*  ja:初期化ファイルを解放する
+    profile_list,リスト                                                     */
 static void
 profile_list_free (ProfileList *profile_list)
 {
@@ -197,12 +197,12 @@ profile_list_free (ProfileList *profile_list)
 
 /******************************************************************************
 *                                                                             *
-* ja:t@C֐Q(Ǝ)                                               *
+* ja:初期化ファイル関数群(独自)                                               *
 *                                                                             *
 ******************************************************************************/
-/*  ja:t@CJ
-    file,t@C
-     RET,vt@C                                                       */
+/*  ja:初期化ファイルを開く
+    file,ファイル名
+     RET,プロファイル                                                       */
 Profile *
 profile_open (const gchar *file)
 {
@@ -267,9 +267,9 @@ profile_open (const gchar *file)
 }
 
 
-/*  ja:t@C
-    profile,vt@C
-        RET,TRUE:I,FALSE:G[                                      */
+/*  ja:初期化ファイルを閉じる
+    profile,プロファイル
+        RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
 profile_close (Profile *profile)
 {
@@ -277,7 +277,7 @@ profile_close (Profile *profile)
     return TRUE;
   if (profile->edit)
     {
-      /* ja:ύXƂ */
+      /* ja:変更があったとき */
       gchar *text;
 
       text = profile_list_to_text (profile->list);
@@ -295,11 +295,11 @@ profile_close (Profile *profile)
 }
 
 
-/*  ja:t@C當擾
-    profile,vt@C
-    section,ZNV
-        key,L[
-        RET,,NULL:G[                                              */
+/*  ja:初期化ファイルから文字列を取得する
+    profile,プロファイル
+    section,セクション
+        key,キー
+        RET,文字列,NULL:エラー                                              */
 gchar *
 profile_get_string (Profile     *profile,
                     const gchar *section,
@@ -321,12 +321,12 @@ profile_get_string (Profile     *profile,
 }
 
 
-/*  ja:t@Cl̃TCY擾
-    profile,vt@C
-    section,ZNV
-        key,L[
-       type,^Cv
-        RET,oCg,0:G[                                               */
+/*  ja:初期化ファイルから値のサイズ取得する
+    profile,プロファイル
+    section,セクション
+        key,キー
+       type,タイプ
+        RET,バイト数,0:エラー                                               */
 gsize
 profile_get_size (Profile     *profile,
                   const gchar *section,
@@ -377,14 +377,14 @@ profile_get_size (Profile     *profile,
 }
 
 
-/*  ja:t@Cl擾
-    profile,vt@C
-    section,ZNV
-        key,L[
-      value,lobt@
-       size,lobt@̃TCY
-       type,^Cv
-        RET,TRUE:I,FALSE:G[                                      */
+/*  ja:初期化ファイルから値を取得する
+    profile,プロファイル
+    section,セクション
+        key,キー
+      value,値を入れるバッファ
+       size,値を入れるバッファのサイズ
+       type,タイプ
+        RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
 profile_get_value (Profile     *profile,
                    const gchar *section,
@@ -455,14 +455,14 @@ profile_get_value (Profile     *profile,
 }
 
 
-/*  ja:t@Cɒlݒ肷
-    profile,vt@C
-    section,ZNV
-        key,L[
-      value,lĂobt@
-       size,lĂobt@̃TCY
-       type,^Cv
-        RET,TRUE:I,FALSE:G[                                      */
+/*  ja:初期化ファイルに値を設定する
+    profile,プロファイル
+    section,セクション
+        key,キー
+      value,値が入っているバッファ
+       size,値が入っているバッファのサイズ
+       type,タイプ
+        RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
 profile_set_value (Profile       *profile,
                    const gchar   *section,
@@ -490,7 +490,7 @@ profile_set_value (Profile       *profile,
         {
           if (q)
             {
-              /* ja:Õf[^Ƃ̊ԂɃXy[X */
+              /* ja:前のデータとの間にスペースを入れる */
               p = g_malloc (sizeof (ProfileList));
               p->type = PROFILE_DATA_TYPE_SPACE;
               p->data = p->section = p->key = p->value = NULL;
@@ -499,7 +499,7 @@ profile_set_value (Profile       *profile,
               q->next = p;
               q = p;
             }
-          /* ja:ZNVL[ȂƂɂ̓ZNV */
+          /* ja:セクションもキーもないときにはセクションを作る */
           p = g_malloc (sizeof (ProfileList));
           p->type = PROFILE_DATA_TYPE_SECTION;
           p->data = g_strdup_printf ("[%s]", section);
@@ -521,7 +521,7 @@ profile_set_value (Profile       *profile,
       while (q->type == PROFILE_DATA_TYPE_SPACE && q->section
                             && g_strcmp (p->section, section) == 0 && q->prev)
         q = q->prev;
-      /* ja:ZNV̍ŌɃL[ */
+      /* ja:セクションの最後にキーを作る */
       p = g_malloc (sizeof (ProfileList));
       p->type = PROFILE_DATA_TYPE_KEY;
       p->data = g_strdup_printf ("%s=", key);
@@ -569,10 +569,10 @@ profile_set_value (Profile       *profile,
 }
 
 
-/*  ja:t@C̃ZNV폜
-    profile,vt@C
-    section,ZNV
-        RET,TRUE:I,FALSE:G[                                      */
+/*  ja:初期化ファイルのセクションを削除する
+    profile,プロファイル
+    section,セクション
+        RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
 profile_delete_section (Profile     *profile,
                         const gchar *section)
@@ -603,11 +603,11 @@ profile_delete_section (Profile     *profile,
 }
 
 
-/*  ja:t@C̃L[폜
-    profile,vt@C
-    section,ZNV
-        key,L[
-        RET,TRUE:I,FALSE:G[                                      */
+/*  ja:初期化ファイルのキーを削除する
+    profile,プロファイル
+    section,セクション
+        key,キー
+        RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
 profile_delete_key (Profile     *profile,
                     const gchar *section,
@@ -640,9 +640,9 @@ profile_delete_key (Profile     *profile,
 }
 
 
-/*  ja:t@C̃ZNV񋓂
-    profile,vt@C
-        RET,ZNṼXg,NULL:G[                                  */
+/*  ja:初期化ファイルのセクションを列挙する
+    profile,プロファイル
+        RET,セクションのリスト,NULL:エラー                                  */
 GList *
 profile_enum_section (Profile *profile)
 {
@@ -653,20 +653,20 @@ profile_enum_section (Profile *profile)
     return NULL;
   for (p = profile->list; p; p = p->next)
     if (p->section && (!glist || !g_list_find_custom (glist, p->section,
-                                                        (GCompareFunc)strcmp)))
-      glist = g_list_insert_sorted (glist, p->section, (GCompareFunc)strcmp);
+                                                    (GCompareFunc)g_strcmp)))
+      glist = g_list_insert_sorted (glist, p->section, (GCompareFunc)g_strcmp);
   for (p = profile->sublist; p; p = p->next)
     if (p->section && (!glist || !g_list_find_custom (glist, p->section,
-                                                        (GCompareFunc)strcmp)))
-      glist = g_list_insert_sorted (glist, p->section, (GCompareFunc)strcmp);
+                                                    (GCompareFunc)g_strcmp)))
+      glist = g_list_insert_sorted (glist, p->section, (GCompareFunc)g_strcmp);
   return glist;
 }
 
 
-/*  ja:t@C̃L[񋓂
-    profile,vt@C
-    section,ZNV
-        RET,ZNṼXg,NULL:G[                                  */
+/*  ja:初期化ファイルのキーを列挙する
+    profile,プロファイル
+    section,セクション
+        RET,セクションのリスト,NULL:エラー                                  */
 GList *
 profile_enum_key (Profile     *profile,
                   const gchar *section)
@@ -679,20 +679,20 @@ profile_enum_key (Profile     *profile,
   for (p = profile->list; p; p = p->next)
     if (p->section && p->key && g_strcmp (p->section, section) == 0
                             && (!glist || !g_list_find_custom (glist, p->key,
-                                                        (GCompareFunc)strcmp)))
-      glist = g_list_insert_sorted (glist, p->key, (GCompareFunc)strcmp);
+                                                    (GCompareFunc)g_strcmp)))
+      glist = g_list_insert_sorted (glist, p->key, (GCompareFunc)g_strcmp);
   for (p = profile->sublist; p; p = p->next)
     if (p->section && p->key && g_strcmp (p->section, section) == 0
                             && (!glist || !g_list_find_custom (glist, p->key,
-                                                        (GCompareFunc)strcmp)))
-      glist = g_list_insert_sorted (glist, p->key, (GCompareFunc)strcmp);
+                                                    (GCompareFunc)g_strcmp)))
+      glist = g_list_insert_sorted (glist, p->key, (GCompareFunc)g_strcmp);
   return glist;
 }
 
 
 /******************************************************************************
 *                                                                             *
-* ja:t@C֐Q(݊)                                               *
+* ja:初期化ファイル関数群(互換)                                               *
 *                                                                             *
 ******************************************************************************/
 Profile *
@@ -751,7 +751,7 @@ profile_keyfile_load_from_data (Profile      *profile,
     *error = NULL;
   if (!profile)
     return FALSE;
-  /* ja:Xg */
+  /* ja:リスト解放 */
   profile_list_free (profile->list);
   profile_list_free (profile->sublist);
   profile->list = profile->sublist = NULL;
