@@ -1,10 +1,10 @@
 /*
     orzcharlist
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "orzcharlist.h"
 #include "orzcharset.h"
@@ -22,21 +21,11 @@
 #include <gdk/gdkkeysyms.h>
 
 
-static void orz_charlist_class_init (OrzCharlistClass *klass);
-static void orz_charlist_init       (OrzCharlist      *charlist);
-static void orz_charlist_escape     (OrzCharlist      *charlist);
-
-
-static GtkDialogClass *parent_class = NULL;
-
-
 enum
 {
   ESCAPE_SIGNAL,
   LAST_SIGNAL
 };
-
-
 enum
 {
   TARGET_GTK_TREE_MODEL_ROW
@@ -49,48 +38,15 @@ static gint orz_charlist_signals[LAST_SIGNAL] = {0};
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-orz_charlist_get_type (void)
-{
-  static GType orz_charlist_type = 0;
-
-  if (!orz_charlist_type)
-    {
-      const static GTypeInfo charlist_info =
-      {
-        sizeof (OrzCharlistClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)orz_charlist_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (OrzCharlist),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc)orz_charlist_init,
-      };
-
-      orz_charlist_type = g_type_register_static (GTK_TYPE_DIALOG,
-                                            "OrzCharlist", &charlist_info, 0);
-    }
-
-  return orz_charlist_type;
-}
+G_DEFINE_TYPE (OrzCharlist, orz_charlist, GTK_TYPE_DIALOG);
+static void orz_charlist_escape (OrzCharlist *charlist);
 
 
 static void
 orz_charlist_class_init (OrzCharlistClass *klass)
 {
-  GObjectClass *gobject_class;
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   GtkBindingSet *binding_set;
 
-  gobject_class = (GObjectClass*) klass;
-  object_class = (GtkObjectClass*) klass;
-  widget_class = (GtkWidgetClass*) klass;
-
-  parent_class = g_type_class_peek_parent (klass);
-
   klass->escape = orz_charlist_escape;
 
   orz_charlist_signals[ESCAPE_SIGNAL]
