@@ -1,6 +1,6 @@
 /*
     orzcharset
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -185,44 +185,54 @@ gchar *
 orz_charset_get_candidate (OrzCharset *charset)
 {
   gchar *candidate = NULL;
-  gint i;
-#if GTK_CHECK_VERSION(2,4,0)
-  GtkTreeModel *model;
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  GList *glist;
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
 
-  if (!charset)
-    return NULL;
-#if GTK_CHECK_VERSION(2,4,0)
-  model = gtk_combo_box_get_model (GTK_COMBO_BOX (charset));
-  for (i = gtk_tree_model_iter_n_children (model, NULL) - 1; i >= 0; i--)
+  if (charset)
     {
-      gchar *str, *tmp;
-      GtkTreeIter iter;
+#if GTK_CHECK_VERSION(2,4,0)
+      gint i;
+      GtkTreeModel *model;
 
-      gtk_tree_model_iter_nth_child (model, &iter, NULL, i);
-      gtk_tree_model_get (model, &iter, 0, &tmp, -1);
-      str = g_strconcat (tmp, ",", candidate, NULL);
-      g_free (tmp);
-      g_free (candidate);
-      candidate = str;
-    }
+      model = gtk_combo_box_get_model (GTK_COMBO_BOX (charset));
+      for (i = gtk_tree_model_iter_n_children (model, NULL) - 1; i >= 0; i--)
+        {
+          gchar *str, *tmp;
+          GtkTreeIter iter;
+
+          gtk_tree_model_iter_nth_child (model, &iter, NULL, i);
+          gtk_tree_model_get (model, &iter, 0, &tmp, -1);
+          str = g_strconcat (tmp, candidate ? "," : NULL, candidate, NULL);
+          g_free (tmp);
+          g_free (candidate);
+          candidate = str;
+        }
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-  glist = gtk_container_get_children
+      GList *glist;
+
+      glist = gtk_container_get_children
                                 (GTK_CONTAINER (GTK_COMBO (charset)->list));
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
-    {
-      gchar *str;
+      for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+        {
+          const gchar *text;
 
-      str = g_strconcat (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-            (GTK_BIN (g_list_nth_data (glist, i))))), ",", candidate, NULL);
-      g_free (candidate);
-      candidate = str;
-    }
-   g_list_free (glist);
+          text = gtk_label_get_text
+                    (GTK_LABEL (gtk_bin_get_child (GTK_BIN (glist->data))));
+          if (candidate)
+            {
+              gchar *str;
+
+              str = g_strconcat (candidate, ",", text, NULL);
+              g_free (candidate);
+              candidate = str;
+            }
+          else
+            {
+              candidate = g_strdup (text);
+            }
+        }
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-   return candidate;
+    }
+  return candidate;
 }
 
 
@@ -231,8 +241,8 @@ orz_charset_get_candidate (OrzCharset *charset)
     candidate,文字符号化方式の候補
           RET,TRUE:正常終了,FALSE:エラー                                    */
 gboolean
-orz_charset_add_candidate (OrzCharset *charset,
-                            const gchar *candidate)
+orz_charset_add_candidate (OrzCharset  *charset,
+                           const gchar *candidate)
 {
   gboolean result = TRUE;
   gchar **str;
@@ -301,8 +311,10 @@ orz_charset_add_candidate (OrzCharset *charset,
         g_list_free (glist);
         item = gtk_list_item_new_with_label (str[i]);
         gtk_widget_show (item);
+        glist = g_list_append (NULL, item);
         gtk_list_insert_items (GTK_LIST (GTK_COMBO (charset)->list),
-                                            g_list_append (NULL, item), j + 1);
+                                                                glist, j + 1);
+        g_list_free (glist);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
       }
     else
