@@ -1,10 +1,10 @@
 /*
     orzhistory
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,21 +13,12 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "orzhistory.h"
 #include "misc/fileio.h"
 
 
-static void orz_history_class_init (OrzHistoryClass *klass);
-static void orz_history_init       (OrzHistory      *history);
-static void orz_history_dispose    (GObject         *object);
-
-
-static GObjectClass *parent_class = NULL;
-
-
 enum
 {
   ACTIVATE_SIGNAL,
@@ -48,31 +39,8 @@ static gint orz_history_signals[LAST_SIGNAL] = {0};
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GType
-orz_history_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      const static GTypeInfo info =
-      {
-        sizeof (OrzHistoryClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)orz_history_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (OrzHistory),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc)orz_history_init,
-      };
-
-      type = g_type_register_static (G_TYPE_OBJECT, "OrzHistory", &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (OrzHistory, orz_history, G_TYPE_OBJECT);
+static void orz_history_dispose (GObject *object);
 
 
 static void
@@ -80,14 +48,14 @@ orz_history_class_init (OrzHistoryClass *klass)
 {
   GObjectClass *object_class;
 
-  parent_class = g_type_class_peek_parent (klass);
-  object_class = (GObjectClass *)klass;
-
+  object_class = G_OBJECT_CLASS (klass);
   object_class->dispose = orz_history_dispose;
 
+  klass->activate = NULL;
+
   orz_history_signals[ACTIVATE_SIGNAL]
                 = g_signal_new ("activate",
-                                G_TYPE_FROM_CLASS (object_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzHistoryClass, activate),
                                 NULL, NULL,
@@ -115,7 +83,6 @@ orz_history_init (OrzHistory *history)
 static void
 orz_history_remove (OrzHistory *history)
 {
-
   if (history && history->glist)
     {
       OrzHistoryItem *history_item;
@@ -169,8 +136,9 @@ orz_history_remove (OrzHistory *history)
 static void
 orz_history_dispose (GObject *object)
 {
-  OrzHistory *history = ORZ_HISTORY (object);
+  OrzHistory *history;
 
+  history = ORZ_HISTORY (object);
   while (history->glist)
     orz_history_remove (history);
   if (history->menu_shell)
@@ -180,8 +148,8 @@ orz_history_dispose (GObject *object)
                                                     history->handler_destroy);
       history->menu_shell = NULL;
     }
-  if (G_OBJECT_CLASS (parent_class)->dispose)
-    G_OBJECT_CLASS (parent_class)->dispose (object);
+  if (G_OBJECT_CLASS (orz_history_parent_class)->dispose)
+    G_OBJECT_CLASS (orz_history_parent_class)->dispose (object);
 }
 
 
@@ -379,15 +347,10 @@ orz_history_get_file (OrzHistory *history)
 
   if (history)
     {
-      gint i;
+      GList *gl;
 
-      for (i = g_list_length (history->glist) - 1; i >= 0; i--)
-        {
-          OrzHistoryItem *history_item;
-
-          history_item = g_list_nth_data (history->glist, i);
-          glist = g_list_prepend (glist, history_item->file);
-        }
+      for (gl = g_list_first (history->glist); gl; gl = g_list_next (gl))
+        glist = g_list_append (glist, ((OrzHistoryItem *)gl->data)->file);
     }
   return glist;
 }
@@ -414,43 +377,38 @@ orz_history_set_menu (OrzHistory *history,
 {
   if (history)
     {
-      gint i;
-
       if (history->menu_shell)
         {
+          GList *glist;
+
           if (history->handler_destroy)
             {
               g_signal_handler_disconnect (G_OBJECT (history->menu_shell),
                                                     history->handler_destroy);
               history->handler_destroy = 0;
             }
-          if (history->glist)
-            for (i = g_list_length (history->glist) - 1; i >= 0; i--)
-              {
-                OrzHistoryItem *history_item;
-
-                history_item = g_list_nth_data (history->glist, i);
-                if (history_item->menu_item)
-                  gtk_container_remove (GTK_CONTAINER (history->menu_shell),
-                                                    history_item->menu_item);
-              }
+          for (glist = g_list_first (history->glist);
+                                            glist; glist = g_list_next (glist))
+            if (((OrzHistoryItem *)glist->data)->menu_item)
+              gtk_container_remove (GTK_CONTAINER (history->menu_shell),
+                                ((OrzHistoryItem *)glist->data)->menu_item);
         }
       history->menu_shell = menu_shell;
       history->position = position;
       if (history->menu_shell)
         {
-          GList *glist;
+          GList *gl, *glist;
 
           history->handler_destroy
                         = g_signal_connect (G_OBJECT (menu_shell), "destroy",
                         G_CALLBACK (orz_history_destroy_menu_shell), history);
           glist = history->glist;
           history->glist = NULL;
-          for (i = g_list_length (glist) - 1; i >= 0; i--)
+          for (gl = g_list_last (glist); gl; gl = g_list_previous (gl))
             {
               OrzHistoryItem *history_item;
 
-              history_item = g_list_nth_data (glist, i);
+              history_item = gl->data;
               orz_history_add_file (history, history_item->file);
               g_free (history_item->file);
               g_free (history_item);
