@@ -1,6 +1,6 @@
 /*
     orzmdi
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ struct _OrzMdiTab
   gboolean created;     /* ja:TRUE:新規作成,FALSE:既存ファイル */
   gboolean edited;      /* ja:TRUE:編集済み,FALSE:未編集 */
   gchar *file;
-  gint same;            /* -2:名前のみ,-1:フルパス,0...:フルパス+数字 */
+  gint same;            /* ja:-2:名前のみ,-1:フルパス,0...:フルパス+数字 */
   GtkWidget *child, *image, *label;
   OrzMdi *mdi;
 };
@@ -98,18 +98,17 @@ static void
 file_add_edit (OrzMdi    *mdi,
                OrzMdiTab *tab0)
 {
-  gint i;
-  GList *glist;
+  GList *gl, *glist;
   OrzMdiTab *tab1;
 
   tab0->same = -2;
   /* ja:ファイル名を調べる */
   glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   /* ja:同名同パスを調べる */
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
+  for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
     {
       tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
       if (tab1 && tab0 != tab1 && g_strfilecmp (tab0->file, tab1->file) == 0)
         {
           if (tab1->same < 0)
@@ -128,10 +127,10 @@ file_add_edit (OrzMdi    *mdi,
       /* ja:同名同パスはないとき */
       /* ja:同名異パスを調べる */
       name0 = g_path_get_basename (tab0->file);
-      for (i = g_list_length (glist) - 1; i >= 0; i--)
+      for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
         {
           tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
           if (tab1 && tab0 != tab1)
             {
               gchar *name1;
@@ -151,7 +150,7 @@ file_add_edit (OrzMdi    *mdi,
             }
         }
       g_free (name0);
-      if (i >= 0)
+      if (gl)
         tab0->same = -1;
     }
   g_list_free (glist);
@@ -163,18 +162,18 @@ file_remove_edit (OrzMdi      *mdi,
                   OrzMdiTab   *tab0,
                   const gchar *file)
 {
-  gint i, count0 = 0, count1 = 0;
+  gint count0 = 0, count1 = 0;
   gchar *name0, *name1;
-  GList *glist;
+  GList *gl, *glist;
   OrzMdiTab *tab1;
 
   /* ja:ファイル名を調べる */
   glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   name0 = g_path_get_basename (tab0->file);
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
+  for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
     {
       tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
       if (tab1 && tab0 != tab1)
         {
           /* ja:同名同パスを調べる */
@@ -194,12 +193,11 @@ file_remove_edit (OrzMdi      *mdi,
       name2 = file ? g_path_get_basename (file) : NULL;
       if (!name2 || g_strfilecmp (name0, name2) != 0)
         /* 名前が変わっているとき */
-        for (i = g_list_length (glist) - 1; i >= 0; i--)
+        for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
           {
             /* ja:同名のファイルを通常表示に変更する */
             tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-                            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))),
-                                                                "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
             if (tab1 && tab0 != tab1)
               {
                 /* ja:同名を調べる */
@@ -215,18 +213,21 @@ file_remove_edit (OrzMdi      *mdi,
       g_free (name2);
     }
   else if (count0 == 1)/* ja:同名同パスが1つだけある(異パスは複数)とき */
-    for (i = g_list_length (glist) - 1; i >= 0; i--)
-      {
-        /* ja:同名同パスのファイルをフルパスに変更する */
-        tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
-        /* ja:同名同パスを調べる */
-        if (tab1 && tab0 != tab1 && g_strfilecmp (tab0->file, tab1->file) == 0)
-          {
-            tab1->same = -1;
-            orz_mdi_label_markup (tab1);
-          }
-      }
+    {
+      for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
+        {
+          /* ja:同名同パスのファイルをフルパスに変更する */
+          tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
+          /* ja:同名同パスを調べる */
+          if (tab1 && tab0 != tab1
+                                && g_strfilecmp (tab0->file, tab1->file) == 0)
+            {
+              tab1->same = -1;
+              orz_mdi_label_markup (tab1);
+            }
+        }
+    }
   g_free (name0);
   g_list_free (glist);
 }
@@ -519,28 +520,67 @@ orz_mdi_tab_drag_data_received (GtkWidget        *widget,
 }
 
 
-/*  ja:ページのタブを作る
+/*  ja:ページを最後に追加する
           mdi,ウィジェット
         child,内容
          file,ファイル名
       created,TRUE:新規作成,FALSE:既存ファイル
     page_data,ページデータ
-          RET,ウィジェット                                                  */
-static GtkWidget *
-orz_mdi_create_tab_label (OrzMdi         *mdi,
-                          GtkWidget      *child,
-                          const gchar    *file,
-                          const gboolean  created,
-                          gpointer        page_data)
+          RET,ページ(0...,-1:エラー)                                        */
+gint
+orz_mdi_append_page (OrzMdi         *mdi,
+                     GtkWidget      *child,
+                     const gchar    *file,
+                     const gboolean  created,
+                     gpointer        page_data)
 {
+  return orz_mdi_insert_page (mdi, child, -1, file, created, page_data);
+}
+
+
+/*  ja:ページを最初に追加する
+          mdi,ウィジェット
+        child,内容
+         file,ファイル名
+      created,TRUE:新規作成,FALSE:既存ファイル
+    page_data,ページデータ
+          RET,ページ(0...,-1:エラー)                                        */
+gint
+orz_mdi_prepend_page (OrzMdi         *mdi,
+                      GtkWidget      *child,
+                      const gchar    *file,
+                      const gboolean  created,
+                      gpointer        page_data)
+{
+  return orz_mdi_insert_page (mdi, child, 0, file, created, page_data);
+}
+
+
+/*  ja:ページを挿入する
+          mdi,ウィジェット
+        child,内容
+     position,位置(0...)
+         file,ファイル名
+      created,TRUE:新規作成,FALSE:既存ファイル
+    page_data,ページデータ
+       RET,ページ(0...,-1:エラー)                                           */
+gint
+orz_mdi_insert_page (OrzMdi         *mdi,
+                     GtkWidget      *child,
+                     const gint      position,
+                     const gchar    *file,
+                     const gboolean  created,
+                     gpointer        page_data)
+{
+  gint page_num;
   GdkPixbuf *pixbuf;
-  GtkWidget *button, *hbox, *event;
   GtkTargetEntry dnd_entries[1] = {{"ORZ_MDI_TAB",
                                     GTK_TARGET_SAME_APP, TARGET_ORZ_MDI_TAB}};
+  GtkWidget *button, *hbox, *event;
   OrzMdiTab *tab;
 
-  if (!mdi)
-    return NULL;
+  if (!mdi || !child)
+    return -1;
   tab = g_malloc0 (sizeof (OrzMdiTab));
   tab->page_data = page_data;
   tab->created = created;
@@ -574,6 +614,9 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
   gtk_widget_show (hbox);
   /* ja:ツールチップス */
   event = gtk_event_box_new ();
+#if GLIB_CHECK_VERSION(2,4,0)
+  gtk_event_box_set_visible_window (GTK_EVENT_BOX (event), FALSE);
+#endif /* GLIB_CHECK_VERSION(2,4,0) */
   gtk_container_add (GTK_CONTAINER (event), hbox);
   gtk_tooltips_set_tip (mdi->tooltips, event, tab->file, tab->file);
   g_object_set_data (G_OBJECT (event), "user_data", tab);
@@ -595,144 +638,13 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
                             G_CALLBACK (orz_mdi_tab_drag_data_get), NULL);
   g_signal_connect (G_OBJECT (event), "drag_data_received",
                             G_CALLBACK (orz_mdi_tab_drag_data_received), NULL);
-
-  return event;
-}
-
-
-/*  ja:ページを最後に追加する
-          mdi,ウィジェット
-        child,内容
-         file,ファイル名
-      created,TRUE:新規作成,FALSE:既存ファイル
-    page_data,ページデータ
-          RET,ページ(0...,-1:エラー)                                        */
-gint
-orz_mdi_append_page (OrzMdi         *mdi,
-                     GtkWidget      *child,
-                     const gchar    *file,
-                     const gboolean  created,
-                     gpointer        page_data)
-{
-  return orz_mdi_insert_page_menu (mdi, child, NULL, -1,
-                                                    file, created, page_data);
-}
-
-
-/*  ja:ページを最後に追加する
-          mdi,ウィジェット
-        child,内容
-         menu,メニュー
-         file,ファイル名
-      created,TRUE:新規作成,FALSE:既存ファイル
-    page_data,ページデータ
-          RET,ページ(0...,-1:エラー)                                        */
-gint
-orz_mdi_append_page_menu (OrzMdi         *mdi,
-                          GtkWidget      *child,
-                          GtkWidget      *menu,
-                          const gchar    *file,
-                          const gboolean  created,
-                          gpointer        page_data)
-{
-  return orz_mdi_insert_page_menu (mdi, child, menu, -1,
-                                                    file, created, page_data);
-}
-
-
-/*  ja:ページを最初に追加する
-          mdi,ウィジェット
-        child,内容
-         file,ファイル名
-      created,TRUE:新規作成,FALSE:既存ファイル
-    page_data,ページデータ
-          RET,ページ(0...,-1:エラー)                                        */
-gint
-orz_mdi_prepend_page (OrzMdi         *mdi,
-                      GtkWidget      *child,
-                      const gchar    *file,
-                      const gboolean  created,
-                      gpointer        page_data)
-{
-  return orz_mdi_insert_page_menu (mdi, child, NULL, 0,
-                                                    file, created, page_data);
-}
-
-
-/*  ja:ページを最初に追加する
-          mdi,ウィジェット
-        child,内容
-         menu,メニュー
-         file,ファイル名
-      created,TRUE:新規作成,FALSE:既存ファイル
-    page_data,ページデータ
-          RET,ページ(0...,-1:エラー)                                        */
-gint
-orz_mdi_prepend_page_menu (OrzMdi         *mdi,
-                           GtkWidget      *child,
-                           GtkWidget      *menu,
-                           const gchar    *file,
-                           const gboolean  created,
-                           gpointer        page_data)
-{
-  return orz_mdi_insert_page_menu (mdi, child, menu, 0,
-                                                    file, created, page_data);
-}
-
-
-/*  ja:ページを挿入する
-          mdi,ウィジェット
-        child,内容
-     position,位置(0...)
-         file,ファイル名
-      created,TRUE:新規作成,FALSE:既存ファイル
-    page_data,ページデータ
-       RET,ページ(0...,-1:エラー)                                           */
-gint
-orz_mdi_insert_page (OrzMdi         *mdi,
-                     GtkWidget      *child,
-                     const gint      position,
-                     const gchar    *file,
-                     const gboolean  created,
-                     gpointer        page_data)
-{
-  return orz_mdi_insert_page_menu (mdi, child, NULL, position,
-                                                    file, created, page_data);
-}
-
-
-/*  ja:ページを挿入する
-          mdi,ウィジェット
-        child,内容
-         menu,メニュー
-     position,位置(0...)
-         file,ファイル名
-      created,TRUE:新規作成,FALSE:既存ファイル
-    page_data,ページデータ
-       RET,ページ(0...,-1:エラー)                                           */
-gint
-orz_mdi_insert_page_menu (OrzMdi         *mdi,
-                          GtkWidget      *child,
-                          GtkWidget      *menu,
-                          const gint      position,
-                          const gchar    *file,
-                          const gboolean  created,
-                          gpointer        page_data)
-{
-  gint page_num = -1;
-  GtkWidget *tab_label;
-
-  tab_label = orz_mdi_create_tab_label (mdi, child, file, created, page_data);
-  if (tab_label)
-    {
-      page_num = gtk_notebook_insert_page_menu (GTK_NOTEBOOK (mdi), child,
-                                                    tab_label, menu, position);
-      g_signal_emit (mdi,
-                     orz_mdi_signals[ADD_WINDOW_SIGNAL],
-                     0,
-                     page_num,
-                     page_data);
-    }
+  page_num = gtk_notebook_insert_page (GTK_NOTEBOOK (mdi), child,
+                                                            event, position);
+  g_signal_emit (mdi,
+                 orz_mdi_signals[ADD_WINDOW_SIGNAL],
+                 0,
+                 page_num,
+                 page_data);
   return page_num;
 }
 
