@@ -981,7 +981,11 @@ command_next (GtkWidget *widget,
                                                             find_ignorecase);
   /* ja:中断ボタン */
   abort_box_end ();
-  if (abort_break && !result)
+  if (result)
+    {
+      gtk_widget_grab_focus (tmaid->drawing);
+    }
+  else if (abort_break)
     {
       GtkWidget *dialog;
 
