@@ -62,7 +62,7 @@ edit_get_width (TmaidWindow *tmaid,
 
   p = edit_get_line_buf (&tmaid->start, &tmaid->off, y);
   if (p->margin)
-    while (data_pos < p->length - 1)
+    while (data_pos + 1 < p->length)
       if (p->text[data_pos] == '\t')
         {
           width = (width / tmaid->ft.tab + 1) * tmaid->ft.tab;
@@ -159,7 +159,7 @@ edit_get_align_pos (TmaidWindow    *tmaid,
 
   p = edit_get_line_buf (&tmaid->start, &tmaid->off, y);
   if (p->margin)
-    while (screen_pos < x && data_pos < p->length - 1)
+    while (screen_pos < x && data_pos + 1 < p->length)
       if (p->text[data_pos] == '\t')
         {
           if (x < (screen_pos / tmaid->ft.tab + 1) * tmaid->ft.tab)
@@ -647,10 +647,10 @@ edit_put_mem (TmaidWindow *tmaid,
       put->x = edit_get_screen_pos (tmaid, p->length, --put->y);
       /* ja:前の行の右端へ移動 */
     }
-  if (data_pos<p->length)
+  if (data_pos < p->length)
     {
       /* ja:挿入位置以降の文字列をバッファに保存する */
-      temp_leng = p->length-data_pos;
+      temp_leng = p->length - data_pos;
       temp = g_malloc (temp_leng * sizeof (gchar));
       g_memmove (temp, p->text + data_pos, temp_leng * sizeof (gchar));
       p->length = data_pos;
