@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,16 +13,17 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "charset.h"
 #include "command.h"
 #include "edit.h"
 #include "find.h"
 #include "general.h"
+#include "menu.h"
 #include "sigfile.h"
 #include "misc/charuty.h"
+#include "misc/misc.h"
 #include "orz/orzmdi.h"
 
 
@@ -132,35 +133,35 @@ set_menu_bar (TmaidWindow *tmaid)
       created = orz_mdi_get_created (ORZ_MDI (mdi),
                             orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid));
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/file/close"), TRUE);
+                                    "/file/close"), TRUE);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/file/save"), TRUE);
+                                    "/file/save"), TRUE);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/file/saveas"), TRUE);
+                                    "/file/saveas"), TRUE);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/file/reload"), !created);
+                                    "/file/reload"), !created);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/file/print"), TRUE);
+                                    "/file/print"), TRUE);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/file/properties"), TRUE);
+                                    "/file/properties"), TRUE);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/edit"), TRUE);
+                                    "/edit"), TRUE);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/edit/undo"), tmaid->undo != NULL);
+                                    "/edit/undo"), tmaid->undo != NULL);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/edit/redo"), tmaid->redo != NULL);
+                                    "/edit/redo"), tmaid->redo != NULL);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/edit/cut"), tmaid->select.x >= 0);
+                                    "/edit/cut"), tmaid->select.x >= 0);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/edit/copy"), tmaid->select.x >= 0);
+                                    "/edit/copy"), tmaid->select.x >= 0);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/edit/delete"), tmaid->select.x >= 0);
+                                    "/edit/delete"), tmaid->select.x >= 0);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/search"), TRUE);
+                                    "/search"), TRUE);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/search/next"), find_num > 0);
+                                    "/search/next"), find_text[0] != NULL);
       gtk_widget_set_sensitive (misc_find_menu (menu_entries,
-                                        "/search/previous"), find_num > 0);
+                                    "/search/previous"), find_text[0] != NULL);
       gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
                                             "save")), TRUE);
       gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
