@@ -19,7 +19,7 @@
 #define __TMAID_H__
 
 
-#include "gcommon.h"
+#include "misc/gcommon.h"
 
 
 G_BEGIN_DECLS
